Struct Diverging

pub struct Diverging { /* private fields */ }
Diverging commits were found during the Canonical::quorum calculation.

The fmt::Display is used in QuorumError, to provide information on the threshold, base commit, and the two diverging commits, in the calculation.