SymbolicRefs

Struct SymbolicRefs 

pub struct SymbolicRefs(/* private fields */);
Maintains an acyclic set of symbolic references. Note that dangling references are not detected.

Internally, targets are stored as Target, which distinguishes direct (qualified) targets from symbolic (intermediate) ones. This means resolution and cycle-checking can pattern-match on the variant rather than re-parsing the string.

Deserialization Order

Deserialization validates entries in iteration order via TryFrom<IndexMap>. This means deserialization only succeeds if symbolic reference whose target is another symbolic reference appears after that target in the JSON. For example, {"MAIN": "refs/heads/master", "HEAD": "MAIN"} is valid, but {"HEAD": "MAIN", "MAIN": "refs/heads/master"} is not.

To ensure that serialization and deserialization are inverses, we must ensure that insertion order and iteration order are the same. We do this by using IndexMap internally, which preserves this property, and enabling the feature preserve_order of the serde_json crate.

Normally, JSON objects are unordered (see RFC 8259, Sec. 4). Any compatible (de-)serializer must preserve key order.

Implementations

Source

impl SymbolicRefs

Read-only access.

pub fn iter(&self) -> impl Iterator<Item = (&RefString, &Target)>

Returns an iterator over all contained symbolic references, as pairs of their name and Target.

pub fn iter_resolved( &self, ) -> impl Iterator<Item = (&RefString, &Qualified<'static>)>

Returns an iterator over all contained symbolic references that resolve to a direct (qualified) target. The yielded target is the final Qualified reference after chasing through any intermediate symbolic references.

pub fn is_empty(&self) -> bool

Returns true if the set of symbolic references is empty.

Source

impl SymbolicRefs

Utilities for handling of HEAD.

pub fn head(branch_name: &RefString) -> SymbolicRefs

Construct SymbolicRefs for the single symbolic reference HEAD targeting /refs/heads/<branch_name>.

pub fn resolve_head(&self) -> Option<&Qualified<'static>>

Convenience method to get the resolved target of the HEAD reference. Returns the final Qualified reference after chasing the chain. See also SymbolicRefs::head.

Source

impl SymbolicRefs

Mutability.

pub fn combine(&mut self, other: SymbolicRefs) -> Result<(), InsertionError>

Consume other by iteratively inserting into self.