Crate fmt

Crate fmt 

This crate depends on and re-exports from git_ref_format_core.

Macros

Instead of providing procedural macros, like git_ref_format it just provides much simpler declarative macros, guarded by the feature flag macro.

Benefits

  • Does not depend on radicle-git-ext.
  • Does not pull in procedural macro dependencies.
  • Has much smaller compile-time overhead than git_ref_format.

Drawback

The main drawback is that the macros in this crate cannot provide compile time validation of the argument. Thus, these macros must be used in conjunction with testing: If all generated objects are used in tests, and these tests are run, then the guarantees are equally strong. Consumers that do not or cannot test their code should not use the macros then.

Modules

lit
name
refspec

Macros

component
Create a git_ref_format_core::Component from a string literal.
pattern
Create a git_ref_format_core::refspec::PatternString from a string literal.
qualified
Create a git_ref_format_core::Qualified from a string literal.
qualified_pattern
Create a git_ref_format_core::refspec::QualifiedPattern from a string literal.
refname
Create a git_ref_format_core::RefString from a string literal.

Structs

Component
A path component of a RefStr.
DuplicateGlob
Namespaced
A Qualified ref under a git namespace.
Options
Qualified
A fully-qualified refname.
RefStr
RefString

Enums

Error

Functions

check_ref_format
Validate that a string slice is a valid refname.