pub struct Options {
pub allow_onelevel: bool,
pub allow_pattern: bool,
}Fields
allow_onelevel: boolIf false, the refname must contain at least one /.
allow_pattern: boolIf true, the refname may contain exactly one * character.