Module raw

Module raw 

This module re-exports selected items from the git2 crate and provides an extension trait for its git2::Error type to more conveniently handle errors associated with the code git2::ErrorCode::NotFound.

Modules

build

Structs

AnnotatedCommit
A structure to represent an annotated commit, the input to merge and rebase.
Branch
A structure to represent a git branch
Commit
A structure to represent a git commit
Diff
The diff object that contains all individual file deltas.
DiffFindOptions
Control behavior of rename and copy detection
DiffOptions
Structure describing options about how the diff should be executed.
DiffStats
Structure describing a hunk of a diff.
Error
A structure to represent errors coming out of libgit2.
MergeAnalysis
The results of merge_analysis indicating the merge opportunities.
MergeOptions
Options to specify when merging.
Oid
Unique identity of any object (commit, tree, blob, tag).
Reference
A structure to represent a git reference.
Remote
A structure representing a remote of a git repository.
Repository
An owned git repository, representing all state associated with the underlying filesystem.
RepositoryInitOptions
Options which can be used to configure how a repository is initialized
RepositoryOpenFlags
Flags for Repository::open_ext
Signature
A Signature is used to indicate authorship of various actions throughout the library.
Time
Time in a signature
Tree
A structure to represent a git tree

Enums

BranchType
An enumeration for the possible types of branches
Direction
An enumeration of the possible directions for a remote.
ErrorClass
An enumeration of possible categories of things that can have errors when working with a git repository.
ErrorCode
An enumeration of possible errors that can happen when working with a git repository.
FileMode
Valid modes for index and tree entries.
ObjectType
An enumeration all possible kinds objects may have.

Traits

ErrorExt
An extension trait for git2::Error to more conveniently handle errors with the code git2::ErrorCode::NotFound.