pub struct OdbWriter<'repo> { /* private fields */ }Expand description
A structure to represent a git ODB wstream
Implementations
Sourceimpl<'repo> OdbWriter<'repo>
impl<'repo> OdbWriter<'repo>
Sourcepub fn finalize(&mut self) -> Result<Oid, Error>
pub fn finalize(&mut self) -> Result<Oid, Error>
Finish writing to an ODB stream
This method can be used to finalize writing object to the database and get an identifier. The object will take its final name and will be available to the odb. This method will fail if the total number of received bytes differs from the size declared with odb_writer() Attempting write after finishing will be ignored.