ErrorExt

Trait ErrorExt 

pub trait ErrorExt {
    // Required method
    fn is_not_found(&self) -> bool;
}
An extension trait for git2::Error to more conveniently handle errors with the code git2::ErrorCode::NotFound.

Required Methods

fn is_not_found(&self) -> bool

Returns true if the error associated with this error is git2::ErrorCode::NotFound.

Implementors