pub struct CanonicalRefs { /* private fields */ }Expand description
Configuration for canonical references and their Rules.
CanonicalRefs can be converted into a Payload using its From
implementation.
Implementations
Sourceimpl CanonicalRefs
impl CanonicalRefs
Sourcepub fn new(
rules: Rules,
symbolic: SymbolicRefs,
) -> Result<CanonicalRefs, ValidationError>
pub fn new( rules: Rules, symbolic: SymbolicRefs, ) -> Result<CanonicalRefs, ValidationError>
Construct a new CanonicalRefs from a set of Rules and
SymbolicRefs, validating that these may be evaluated to a well
formed set of references when interpreted together.
Sourcepub fn symbolic(&self) -> &SymbolicRefs
pub fn symbolic(&self) -> &SymbolicRefs
Return the SymbolicRefs.