Module update

Module update 

Modules

error

Structs

PayloadUpsert
A change (update or insertion) to particular key within a Payload in a document.

Enums

EditVisibility
EditVisibility allows the visibility of a RawDoc to be edited using the visibility function.

Functions

delegates
Change the delegates of the document and perform some verification based on the new set of delegates.
payload
Change (update or insert) a key in a Payload of the document, using the provided updates.
privacy_allow_list
Change the allow set of a document if the visibility is set to Visibility::Private.
verify
Verify the document.
visibility
Change the visibility of the RawDoc, using the provided EditVisibility.