Modules
- seeds
- Configured public seeds.
Structs
- Config
- Service configuration.
- Connect
Address - Full address used to connect to a remote node.
- Connection
Limits - Connection limits.
- Fetch
Pack Size Limit - Limiter for byte streams.
- Limit
Connections Inbound - Limit
Connections Outbound - Limit
Fetch Concurrency - Limit
Gossip MaxAge - Limit
MaxOpen Files - Limit
Rate Inbound - Limit
Rate Outbound - Limit
Routing MaxAge - Limit
Routing MaxSize - Limits
- Configuration parameters defining attributes of minima and maxima.
- LogLevel
- Rate
Limit - Rate limits for a single connection.
- Rate
Limits - Rate limits for inbound and outbound connections.
- Scope
Scopeprovides a schema forpolicy::Scope, where the inner scope is optional. It is introduced to allow ease migration to a future version ofDefaultSeedingPolicy::Allow, where no or different defaults apply toDefaultSeedingPolicy::Allow::scope.- Workers
Enums
- Address
Config - Proxy configuration.
- Default
Seeding Policy - Default seeding policy. Applies when no repository policies for the given repo are found.
- Network
- Peer-to-peer network.
- Peer
Config - Peer configuration.
- Relay
- Relay configuration.
Type Aliases
- Protocol
Version - Peer-to-peer protocol version.