Module sqlite_ext

Module sqlite_ext 

This module contains definitions for use with the sqlite crate.

Enums

JournalMode
Value for a journal_mode pragma statement. For a description of all variants please refer to https://sqlite.org/pragma.html#pragma_journal_mode. Note that when SQLite documentation talks about “the application”, the application linked against this crate, e.g. Radicle Node, Radicle CLI, and others, is meant.
Synchronous
Value for a synchronous pragma statement. For a description of all variants please refer to https://sqlite.org/pragma.html#pragma_synchronous.