pub struct Device<S> { /* private fields */ }Expand description
A Device identifies the local node through its NodeId, and carries its
signing mechanism.
The signing mechanism is for node specific cryptography, e.g. signing
rad/sigrefs, COB commits, node messages, etc.
Note that a Device can create Signatures and ExtendedSignatures.
It can achieve this as long as S implements Signer<Signature>.
Implementations
Sourceimpl<S> Device<S>
impl<S> Device<S>
Sourcepub fn public_key(&self) -> &PublicKey
pub fn public_key(&self) -> &PublicKey
Return the crypto::PublicKey of the Device.
Sourcepub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Convert the Device into its signer.
This consumes the Device.
Sourceimpl<S> Device<S>where
S: BoxableSigner + 'static,
impl<S> Device<S>where
S: BoxableSigner + 'static,
Sourcepub fn boxed(self) -> BoxedDevice
pub fn boxed(self) -> BoxedDevice
Construct a BoxedDevice from a given Device.