pub enum Command {
Show 23 variants
AnnounceRefs {
rid: RepoId,
},
AnnounceRefsFor {
rid: RepoId,
namespaces: HashSet<PublicKey>,
},
AnnounceInventory,
AddInventory {
rid: RepoId,
},
Config,
ListenAddrs,
Connect {
addr: ConnectAddress,
opts: ConnectOptions,
},
Disconnect {
nid: PublicKey,
},
Seeds {
rid: RepoId,
},
SeedsFor {
rid: RepoId,
namespaces: HashSet<PublicKey>,
},
Sessions,
Session {
nid: PublicKey,
},
Fetch {
rid: RepoId,
nid: PublicKey,
timeout: Duration,
},
Seed {
rid: RepoId,
scope: Scope,
},
Unseed {
rid: RepoId,
},
Follow {
nid: PublicKey,
alias: Option<Alias>,
},
Unfollow {
nid: PublicKey,
},
Block {
nid: PublicKey,
},
Status,
Debug,
NodeId,
Shutdown,
Subscribe,
}Expand description
Command name.
Variants
AnnounceRefs
AnnounceRefsFor insteadAnnounce repository references for given repository to peers.
AnnounceRefsFor
Announce repository references for given repository and namespaces to peers.
Fields
AnnounceInventory
Announce local repositories to peers.
AddInventory
Update node’s inventory.
Config
Get the current node configuration.
ListenAddrs
Get the node’s listen addresses.
Connect
Connect to node with the given address.
Disconnect
Disconnect from a node.
Seeds
SeedsFor insteadLook up seeds for the given repository in the routing table.
SeedsFor
Look up seeds for the given repository in the routing table and report sync status for the given namespaces.
Fields
Sessions
Get the current peer sessions.
Session
Get a specific peer session.
Fetch
Fetch the given repository from the network.
Seed
Seed the given repository.
Unseed
Unseed the given repository.
Follow
Follow the given node.
Unfollow
Unfollow the given node.
Block
Block the given node.
Status
Get the node’s status.
Debug
Get node debug information.
NodeId
Get the node’s NID.
Shutdown
Shutdown the node.
Subscribe
Subscribe to events.
Implementations