NodeId

Type Alias NodeId 

pub type NodeId = PublicKey;
Public identifier of a node device in the network.

Legacy

This is a type alias, providing little protection around evolving a NodeId and having it very tightly coupled with a PublicKey.

Future iterations will change this to provide a better API for working with NodeId’s and their usage in the protocol.

Aliased Type

pub struct NodeId(pub PublicKey);

Tuple Fields

0: PublicKey