pub struct Node { /* private fields */ }Expand description
Node controller.
Implementations
Sourceimpl Node
impl Node
Sourcepub fn call<T>(
&self,
cmd: Command,
timeout: Duration,
) -> Result<LineIter<T>, Error>where
T: DeserializeOwned + Send + 'static,
pub fn call<T>(
&self,
cmd: Command,
timeout: Duration,
) -> Result<LineIter<T>, Error>where
T: DeserializeOwned + Send + 'static,
Call a command on the node.
Sourcepub fn announce(
&mut self,
rid: RepoId,
namespaces: impl IntoIterator<Item = PublicKey>,
timeout: Duration,
announcer: Announcer,
report: impl FnMut(&PublicKey, Progress),
) -> Result<AnnouncerResult, Error>
pub fn announce( &mut self, rid: RepoId, namespaces: impl IntoIterator<Item = PublicKey>, timeout: Duration, announcer: Announcer, report: impl FnMut(&PublicKey, Progress), ) -> Result<AnnouncerResult, Error>
Announce refs of the given rid to the given seeds.
Waits for the seeds to acknowledge the refs or times out if no acknowledgments are received
within the given time.