Target

Struct Target 

pub struct Target { /* private fields */ }
The target for the Announcer to reach.

Implementations

Source

impl Target

pub fn new( preferred_seeds: BTreeSet<PublicKey>, replicas: ReplicationFactor, ) -> Result<Target, TargetError>

pub fn preferred_seeds(&self) -> &BTreeSet<PublicKey>

Get the set of preferred seeds that are trying to be synchronized with.

pub fn replicas(&self) -> &ReplicationFactor

Get the number of replicas that is trying to be reached.

pub fn has_preferred_seeds(&self) -> bool

Check if the target has preferred seeds

pub fn has_replication_factor(&self) -> bool

Check that lower bound of the replication is greater than 0