Struct AnnouncerConfig

pub struct AnnouncerConfig { /* private fields */ }
Configuration of the Announcer.

Implementations

Source

impl AnnouncerConfig

pub fn private( local: PublicKey, replicas: ReplicationFactor, network: PrivateNetwork, ) -> AnnouncerConfig

Setup a private network AnnouncerConfig, populating the AnnouncerConfig’s preferred seeds with the allowed set from the PrivateNetwork.

replicas is the target number of seeds the Announcer should reach before stopping.

local is the NodeId of the local node, to ensure it is excluded from the Announcer process.

pub fn public( local: PublicKey, replicas: ReplicationFactor, preferred_seeds: BTreeSet<PublicKey>, synced: BTreeSet<PublicKey>, unsynced: BTreeSet<PublicKey>, ) -> AnnouncerConfig

Setup a public AnnouncerConfig.

preferred_seeds is the target set of preferred seeds that Announcer should attempt to synchronize with.

synced and unsynced are the set of nodes that are currently synchronized and un-synchronized with, respectively.

replicas is the target number of seeds the Announcer should reach before stopping.

local is the NodeId of the local node, to ensure it is excluded from the Announcer process.