pub struct PrivateNetwork { /* private fields */ }Expand description
A set of nodes that form a private network for fetching from.
This could be the set of allowed nodes for a private repository, using
PrivateNetwork::private_repo
Implementations
Sourceimpl PrivateNetwork
impl PrivateNetwork
pub fn private_repo(doc: &Doc) -> Option<PrivateNetwork>