Module prelude

Module prelude 

Structs

Address
Peer public protocol address.
Did
Filter
Inventory filter used for subscriptions and inventory comparison.
LocalDuration
Time duration as measured locally.
LocalTime
Local time.
PublicKey
The public/verification key.
Refs
The published state of a local repository.
RepoId
A repository identifier.
Signature
Cryptographic signature.
Timestamp
Milliseconds since epoch.

Enums

DisconnectReason
Disconnect reason.
Event
A service event.
Message
Message payload. These are the messages peers send to each other.
Network
Peer-to-peer network.

Traits

WriteStorage
Allows access to individual storage repositories.

Type Aliases

NodeId
Public identifier of a node device in the network.