pub struct RawConfig(/* private fields */);๐Deprecated
Offers utility functions for editing the configuration. Validates on write.
Implementations
Sourceimpl RawConfig
impl RawConfig
Sourcepub fn from_file(path: &Path) -> Result<RawConfig, WriteError>
pub fn from_file(path: &Path) -> Result<RawConfig, WriteError>
Creates a temporary configuration, by reading a configuration file from disk.
Sourcepub fn get_mut(&mut self, config_path: &ConfigPath) -> Option<&mut Value>
pub fn get_mut(&mut self, config_path: &ConfigPath) -> Option<&mut Value>
Get a mutable reference to a configuration value by path, if it exists.
Sourcepub fn unset(&mut self, config_path: &ConfigPath) -> Result<Value, ModifyError>
pub fn unset(&mut self, config_path: &ConfigPath) -> Result<Value, ModifyError>
Delete the specified path.
pub fn push( &mut self, config_path: &ConfigPath, value: ConfigValue, ) -> Result<Value, ModifyError>
pub fn remove( &mut self, config_path: &ConfigPath, value: ConfigValue, ) -> Result<Value, ModifyError>
pub fn set( &mut self, config_path: &ConfigPath, value: ConfigValue, ) -> Result<Value, ModifyError>