Module rad

Module rad 

Enums

CheckoutError
CwdError
ForkError
InitError
JujutsuGitRootError
RemoteError

Statics

PATCHES_REFNAME
Refname used for pushing patches.
REMOTE_COMPONENT
Name of the Radicle storage remote.
REMOTE_NAME
Name of the Radicle storage remote.

Functions

at
Get the repository of project in specified directory
checkout
Checkout a project from storage as a working copy. This effectively does a git-clone from storage.
cwd
Get the RID of the repository in current working directory
fork
init
Initialize a new Radicle project from a git repository.
remote
Get the Radicle (“rad”) remote of a repository, and return the associated project id.
remove_remote
Delete the Radicle (“rad”) remote of a repository.
repo
Get the current Git repository.
repo_jj_git_root
Get the Git repo underlying the current Jujutsu repository.
setup_patch_upstream
Set up patch upstream branch such that git push updates the patch.