Module reactor

Module reactor 

Structs

ProtocolArtifact
Reactor
High-level reactor API wrapping reactor Runtime into a thread and providing basic thread management for it.
Runtime
Internal Reactor runtime which is run in a dedicated thread.

Enums

Action
Actions which can be provided to the Reactor by the ReactionHandler.
Error
Reactor errors

Traits

EventHandler
A resource which can be managed by the reactor.
ReactionHandler
A service which handles reactions to the events generated in the Reactor.
WriteAtomic
The trait guarantees that the data are either written in full or, in case of an error, none of the data is written. Types implementing the trait must also guarantee that multiple attempts to write do not result in data to be written out of the initial ordering.

Type Aliases

NoiseSession
Socks5Session