pub struct Reactor { /* private fields */ }Expand description
High-level reactor API wrapping reactor Runtime into a thread and providing basic thread
management for it.
Apps running the Reactor can interface it and a ReactionHandler via use of the Controller
API.
Implementations
Sourceimpl Reactor
impl Reactor
Sourcepub fn new<H>(service: H, thread_name: String) -> Result<Self, Error>where
H: 'static + ReactionHandler,
pub fn new<H>(service: H, thread_name: String) -> Result<Self, Error>where
H: 'static + ReactionHandler,
Creates new reactor and a service exposing the ReactionHandler to
the reactor.
The service is sent to the newly created reactor thread which runs the
reactor Runtime.
Sourcepub fn controller(&self) -> Controller
pub fn controller(&self) -> Controller
Provides a Controller that can be used to send events to
ReactionHandler via self.