pub struct Runtime<H: ReactionHandler> { /* private fields */ }Expand description
Internal Reactor runtime which is run in a dedicated thread.
This runtime structure does not spawn a thread and is blocking. It implements the actual reactor event loop.