Module git

Module git 

Modules

cob
COB storage Git backend.
paths
temp
trailers
transport

Structs

Ref
A parsed Git reference.
Repository
Git implementation of WriteRepository using the git2 crate.
Storage
TempRepository
A Repository that is created for temporary operations, such as cloning.
Validations
A set of Validation errors that a caller must use.

Enums

Error
Storage error.
RepositoryError
Repository error.
Validation
Validation errors that can occur when verifying the layout of the storage. These errors include checking the validity of the rad/sigrefs contents and the identity of the repository.

Statics

CANONICAL_IDENTITY
NAMESPACES_GLOB
SIGREFS_GLOB