Module store

Module store 

Generic COB storage.

Modules

access
Stores carry Access to indicate allowed access modes. In particular whether writes to the store are allowed.
encoding

Structs

Scope
The Scope of a Store keeps track of what collaborative object is being accessed.
Store
Storage for collaborative objects of a specific type T in a single repository.
Transaction
Allows operations to be batched atomically.

Enums

Error
Store error.

Traits

Cob
A collaborative object. Can be materialized from an operation history.
CobAction
CobWithType
Implementations are statically associated with a particular type name of a collaborative object.

Functions

ops
Get an object’s operations without decoding them.