Store

Struct Store 

pub struct Store<'a, T, Repo, Access> { /* private fields */ }
Storage for collaborative objects of a specific type T in a single repository.

Implementations

Source

impl<'a, T, Repo, Access> Store<'a, T, Repo, Access>
where Repo: ReadRepository + Store<Namespace = PublicKey>, Access: Access,

pub fn open_for( type_name: &'a TypeName, repo: &'a Repo, access: Access, ) -> Result<Store<'a, T, Repo, Access>, Error>

Source

impl<'a, T, Repo, Access> Store<'a, T, Repo, Access>
where Repo: ReadRepository + Store<Namespace = PublicKey>, Access: Access,

pub fn identity(self, identity: Oid) -> Store<'a, T, Repo, Access>

Return a new store with the attached identity.

Source

impl<'a, T, Repo, Access> Store<'a, T, Repo, Access>
where T: CobWithType, Repo: ReadRepository + Store<Namespace = PublicKey>, Access: Access,

pub fn open( repo: &'a Repo, access: Access, ) -> Result<Store<'a, T, Repo, Access>, Error>

Open a new generic store.

Source

impl<'a, 'b, T, Repo, Signer> Store<'a, T, Repo, WriteAs<'b, Signer>>
where T: Cob + Evaluate<Repo>, Repo: ReadRepository + Store<Namespace = PublicKey>,

pub fn transaction( &self, actions: Vec<<T as Cob>::Action>, embeds: Vec<Embed<Uri>>, ) -> Transaction<T, Repo>

Source

impl<'a, 'b, T, Repo, Signer> Store<'a, T, Repo, WriteAs<'b, Signer>>
where T: Cob + Evaluate<Repo>, <T as Cob>::Action: Serialize, Repo: ReadRepository + SignRepository + Store<Namespace = PublicKey>, Signer: Keypair<VerifyingKey = PublicKey> + Signer<Signature> + Signer<ExtendedSignature> + Verifier<Signature>,

pub fn update( &mut self, type_name: &TypeName, object_id: ObjectId, message: &str, actions: impl Into<NonEmpty<<T as Cob>::Action>>, embeds: Vec<Embed<Uri>>, ) -> Result<Updated<T>, Error>

Update an object.

pub fn create( &mut self, message: &str, actions: impl Into<NonEmpty<<T as Cob>::Action>>, embeds: Vec<Embed<Uri>>, ) -> Result<(ObjectId, T), Error>

Create an object.

pub fn remove(&mut self, id: &ObjectId) -> Result<(), Error>

Remove an object.

Source

impl<'a, T, Repo, Access> Store<'a, T, Repo, Access>
where T: Cob + Evaluate<Repo> + 'a, <T as Cob>::Action: Serialize, Repo: ReadRepository + Store<Namespace = PublicKey>, Access: Access,

pub fn get(&self, id: &ObjectId) -> Result<Option<T>, Error>

Get an object.

pub fn all( &self, ) -> Result<impl ExactSizeIterator + use<'a, T, Repo, Access>, Error>

Return all objects.

pub fn is_empty(&self) -> Result<bool, Error>

Return true if the list of issues is empty.

pub fn count(&self) -> Result<usize, Error>

Return objects count.