Store

Trait Store 

pub trait Store: Storage + Storage<ObjectId = Oid, Parent = Oid, Signatures = ExtendedSignature> { }
The Store is an aggregation of the different types of storage traits required for editing CollaborativeObjects.

The backing store being used is expected to be a git backend.

To get started using this trait, you must implement the following for the specific git storage:

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors