component!() { /* proc-macro */ }Expand description
Create a [git_ref_format_core::Component] from a string literal.
The string is validated at compile time, and an unsafe conversion is emitted.
component!() { /* proc-macro */ }Create a [git_ref_format_core::Component] from a string literal.
The string is validated at compile time, and an unsafe conversion is emitted.