pub struct Repository {
pub id: RepoId,
pub backend: Repository,
}Expand description
Git implementation of WriteRepository using the git2 crate.
Fields
id: RepoIdThe repository identifier (RID).
backend: RepositoryThe backing Git repository.
Implementations
Sourceimpl Repository
impl Repository
Sourcepub fn open<P>(path: P, id: RepoId) -> Result<Repository, RepositoryError>
pub fn open<P>(path: P, id: RepoId) -> Result<Repository, RepositoryError>
Open an existing repository.
Sourcepub fn create<P>(
path: P,
id: RepoId,
info: &UserInfo,
) -> Result<Repository, Error>
pub fn create<P>( path: P, id: RepoId, info: &UserInfo, ) -> Result<Repository, Error>
Create a new repository.
Sourcepub fn clean(
&self,
local: &PublicKey,
) -> Result<Vec<PublicKey>, RepositoryError>
pub fn clean( &self, local: &PublicKey, ) -> Result<Vec<PublicKey>, RepositoryError>
Remove all the remotes of a repository that are not the delegates of the repository or the local peer.
N.b. failure to delete remotes or references will not result in an early exit. Instead, this method continues to delete the next available remote or reference.
Sourcepub fn init<G, S>(
doc: &Doc,
storage: &S,
signer: &Device<G>,
) -> Result<(Repository, Oid), RepositoryError>
pub fn init<G, S>( doc: &Doc, storage: &S, signer: &Device<G>, ) -> Result<(Repository, Oid), RepositoryError>
Create the repository’s identity branch.
pub fn inspect(&self) -> Result<(), Error>
Sourcepub fn references(
&self,
) -> Result<impl Iterator<Item = Result<Ref, Error>>, Error>
pub fn references( &self, ) -> Result<impl Iterator<Item = Result<Ref, Error>>, Error>
Iterate over all references.
Sourcepub fn project(&self) -> Result<Project, RepositoryError>
pub fn project(&self) -> Result<Project, RepositoryError>
Get the canonical project information.
pub fn identity_doc_of(&self, remote: &PublicKey) -> Result<Doc, DocError>
pub fn remote_ids( &self, ) -> Result<impl Iterator<Item = Result<PublicKey, Error>>, Error>
pub fn remotes( &self, ) -> Result<impl Iterator<Item = Result<(PublicKey, Remote), Error>>, Error>