FeatureLevel

Enum FeatureLevel 

#[non_exhaustive]
pub enum FeatureLevel { None, Root, Parent, }
The Signed References feature has evolved over time. This enum captures the corresponding “feature level”.

Feature levels are monotonic, in the sense that a greater feature level encompasses all the features of smaller ones.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

The lowest feature level, with least security. It is vulnerable to graft attacks and replay attacks.



Root

Requires IDENTITY_ROOT.



Parent

Requires SIGREFS_PARENT.

Implementations

Source

impl FeatureLevel

pub const LATEST: FeatureLevel = FeatureLevel::Parent