Module sigrefs

Module sigrefs 

Modules

git
Signed References are encoded in the Git commit graph. This module provides traits for interacting with a Git repository to read and write data for Signed References.
read
write

Structs

SignedRefsReader
A SignedRefsReader reads and verifies a commit chain for a rad/sigrefs entry.
VerifiedCommit
A rad/sigrefs that has passed the following verification checks: