Module git

Module git 

Signed References are encoded in the Git commit graph. This module provides traits for interacting with a Git repository to read and write data for Signed References.

Modules

object
Traits for interacting with Git objects, necessary for implementing Radicle Signed References.
reference
Traits for interacting with Git references, necessary for implementing Radicle Signed References.

Structs

Committer
Convenience type that corresponds to an Author.