Reader

Trait Reader 

pub trait Reader {
    // Required method
    fn find_reference(
        &self,
        reference: &Namespaced<'_>,
    ) -> Result<Option<Oid>, FindReference>;
}
Git reference reader, generally a Git repository, or its corresponding Reference Database (Ref DB).

Required Methods

fn find_reference( &self, reference: &Namespaced<'_>, ) -> Result<Option<Oid>, FindReference>

Find the head Oid of the sigrefs reference for the given namespace.

Returns None if the reference does not yet exist.

Errors

Implementors

Source

impl Reader for radicle_node::git::raw::Repository

Source

impl Reader for radicle_node::storage::git::Repository