Committer

Struct Committer 

pub struct Committer {
    pub author: Author,
}
Convenience type that corresponds to an Author.

Most users will want to instantiate this via Committer::from_env_or_now, which automatically constructs a stable Author for tests as well.

Otherwise, an Author can be provided via Committer::new.

Fields

author: Author

Implementations

Source

impl Committer

pub fn from_env_or_now(public_key: &PublicKey) -> Committer

Construct a Committer using the timestamp found at GIT_COMMITTER_DATE,

If GIT_COMMITTER_DATE is unset, it uses the current system time.

The given PublicKey is always used for the email.

In test code, [Committer::stable] is returned.

pub fn new(author: Author) -> Committer

Construct a Committer with the provided Author.

pub fn into_inner(self) -> Author