SignedRefsWriter

Struct SignedRefsWriter 

pub struct SignedRefsWriter<'a, R, S> { /* private fields */ }
A SignedRefsWriter write a commit to the rad/sigrefs reference of a namespace.

To create a new reader, use SignedRefsWriter::new.

The construction expects:

  • A Refs to write to the commit.
  • A NodeId which identifies the namespace for which rad/sigrefs reference should be read and written to.
  • A repository which is the Git repository being used for reading and writing.
  • A signer which is the entity that produces the cryptographic signature over the Refs.

Implementations

Source

impl<'a, R, S> SignedRefsWriter<'a, R, S>
where R: Writer + Reader + Writer + Reader, S: Signer<Signature>,

pub fn new( refs: Refs, namespace: PublicKey, repository: &'a R, signer: &'a S, ) -> SignedRefsWriter<'a, R, S>

Construct a new SignedRefsWriter.

The construction removes the ref SIGREFS_BRANCH from Refs (if present).

When calling SignedRefsWriter::write, if the process is successful, the given Refs will be written to the provided namespace.

pub fn write( self, committer: Committer, message: String, reflog: String, ) -> Result<Update, Write>

Write a commit using the SignedRefsWriter.

The commit written will be composed of:

Note that the SIGREFS_PARENT is not never included in the Refs outside of this process.

This commit is then written to the reference:

refs/namespaces/<namespace>/refs/rad/sigrefs