pub struct Refs(/* private fields */);Expand description
The published state of a local repository.
Implementations
Sourceimpl Refs
impl Refs
pub fn new() -> Refs
Sourcepub fn save<R, S>(
self,
namespace: PublicKey,
committer: Committer,
repo: &R,
signer: &S,
) -> Result<SignedRefs, Error>
pub fn save<R, S>( self, namespace: PublicKey, committer: Committer, repo: &R, signer: &S, ) -> Result<SignedRefs, Error>
Save the signed refs to disk. This creates a new commit on the signed refs branch, and updates the branch pointer.
Sourcepub fn force_save<R, S>(
self,
namespace: PublicKey,
committer: Committer,
repo: &R,
signer: &S,
) -> Result<SignedRefs, Error>
pub fn force_save<R, S>( self, namespace: PublicKey, committer: Committer, repo: &R, signer: &S, ) -> Result<SignedRefs, Error>
Save the signed refs to disk, even if the refs are unchanged.
pub fn insert(&mut self, refname: RefString, target: Oid) -> Option<Oid>
pub fn iter<'a>(&'a self) -> Iter<'a, RefString, Oid>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool