pub struct SignedRefs {
pub at: Oid,
/* private fields */
}Expand description
Verified SignedRefs that keeps track of their content address
Oid.
The signature is a cryptographic signature over the refs. This allows us to easily verify if a set of refs came from a particular key.
Fields
at: OidImplementations
Sourceimpl SignedRefs
impl SignedRefs
Sourcepub fn id(&self) -> PublicKey
pub fn id(&self) -> PublicKey
Returns the NodeId of the SignedRefs.
Sourcepub fn refs(&self) -> &Refs
pub fn refs(&self) -> &Refs
Returns the Refs of the SignedRefs.
Sourcepub fn feature_level(&self) -> FeatureLevel
pub fn feature_level(&self) -> FeatureLevel
Returns the FeatureLevel computed for the signed references.
Sourcepub fn load<R>(remote: PublicKey, repo: &R) -> Result<Option<SignedRefs>, Read>
pub fn load<R>(remote: PublicKey, repo: &R) -> Result<Option<SignedRefs>, Read>
Load the SignedRefs found under remote’s SIGREFS_BRANCH.
This will return None if the branch was not found, all other
errors are returned.
pub fn load_at<R>( oid: Oid, remote: PublicKey, repo: &R, ) -> Result<Option<SignedRefs>, Read>
pub fn iter(&self) -> impl Iterator<Item = (&RefString, &Oid)>
Methods from Deref<Target = Refs>