SignedRefsAt

Struct SignedRefsAt 

pub struct SignedRefsAt {
    pub sigrefs: SignedRefs,
    pub at: Oid,
}
Verified SignedRefs that keeps track of their content address Oid.

Fields

sigrefs: SignedRefsat: Oid

Implementations

Source

impl SignedRefsAt

pub fn load<R>( remote: PublicKey, repo: &R, ) -> Result<Option<SignedRefsAt>, Read>

Load the SignedRefs found under remote’s SIGREFS_BRANCH.

This will return None if the branch was not found, all other errors are returned.

pub fn load_at<R>( at: Oid, remote: PublicKey, repo: &R, ) -> Result<SignedRefsAt, Read>
where R: HasRepoId + Reader + Reader,

pub fn iter(&self) -> impl Iterator<Item = (&RefString, &Oid)>

Methods from Deref<Target = SignedRefs>

pub fn id(&self) -> PublicKey

Returns the NodeId of the SignedRefs.

pub fn refs(&self) -> &Refs

Returns the Refs of the SignedRefs.

Methods from Deref<Target = Refs>

pub fn get(&self, name: &Qualified<'_>) -> Option<Oid>

Get a particular ref.

pub fn head(&self, name: impl AsRef<RefStr>) -> Option<Oid>

Get a particular head ref.

pub fn iter<'a>(&'a self) -> Iter<'a, RefString, Oid>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool