Fingerprint the public key corresponding to the secret key used by
radicle-node.
This allows users to configure the path to the secret key freely, while ensuring that the key is not changed.
In order to achieve this, the fingerprint of the public key
derived from the secret key is stored in the Radicle home
in a file (usually at .radicle/node/fingerprint).
When the node starts up and this file does not exist, it is assumed that
this is the first time the node is started, and the fingerprint is
initialized from the secret key in the keystore.
On subsequent startups, the fingerprint of the public key
derived from the secret key in the keystore is compared to the
fingerprint stored on disk, and if they do not match, the node
refuses to start (this last part is implemented in main.rs).
If the user deletes the fingerprint file, the node will not be able to detect a possible change of the secret key. The consequences of doing this are unclear.
Structs
- Fingerprint
- Fingerprint of a public key.