Modules
- canonical
- env
- Git environment variables.
- fmt
- This crate depends on and re-exports from
git_ref_format_core. - process
- Functions that call to the
gitCLI instead ofgit2. - raw
- This module re-exports selected items from the
git2crate and provides an extension trait for itsgit2::Errortype to more conveniently handle errors associated with the codegit2::ErrorCode::NotFound. - refs
- url
- Git URLs.
Structs
- Url
- A git local transport URL.
- User
Info - The user information used for signing commits and configuring the
nameandemailfields in the Git config. - Verbosity
- Verbosity level for Git commands.
- Version
- A parsed git version.
Enums
Constants
- PROTOCOL_
PORT - Default port of the
gittransport protocol. - VERSION_
REQUIRED - Minimum required git version.
Functions
- commit
- Create a commit and update the given ref to it.
- configure_
remote - Configure a repository’s radicle remote.
- configure_
repository - Configure a radicle repository.
- empty_
commit - Create an empty commit on top of the parent.
- fetch
- Fetch from the given
remote. - head
- Get the repository head.
- head_
refname - init_
default_ branch - initial_
commit - Create an initial empty commit.
- parse_
ref - Parse a
fmt::Qualifiedreference string. It will optionally return the namespace, if present. - parse_
ref_ namespaced - Parse a
fmt::Qualifiedreference string while expecting the reference to start withrefs/namespaces. If the namespace is not present, then an error will be returned. - push
- Push
refspecsto the givenremoteusing the providednamespace. - remote_
refs - List remote refs of a project, given the remote URL.
- run
- Execute a
gitcommand by spawning a child process and collect its output. IfworkingisSome, the command is run as ifgitwas started inworkinginstead of the current working directory, by prepending-C <working>to the command line. - set_
upstream - Set the upstream of the given branch to the given remote.
- version
- Get the system’s git version.
- write_
tree - Write a tree with the given blob at the given path.