This module re-exports selected items from the git2 crate and provides
an extension trait for its git2::Error type to more conveniently handle
errors associated with the code git2::ErrorCode::NotFound.
Modules
Structs
- Annotated
Commit - A structure to represent an annotated commit, the input to merge and rebase.
- Branch
- A structure to represent a git branch
- Commit
- A structure to represent a git commit
- Diff
- The diff object that contains all individual file deltas.
- Diff
Find Options - Control behavior of rename and copy detection
- Diff
Options - Structure describing options about how the diff should be executed.
- Diff
Stats - Structure describing a hunk of a diff.
- Error
- A structure to represent errors coming out of libgit2.
- Merge
Analysis - The results of
merge_analysisindicating the merge opportunities. - Merge
Options - Options to specify when merging.
- Oid
- Unique identity of any object (commit, tree, blob, tag).
- Reference
- A structure to represent a git reference.
- Remote
- A structure representing a remote of a git repository.
- Repository
- An owned git repository, representing all state associated with the underlying filesystem.
- Repository
Init Options - Options which can be used to configure how a repository is initialized
- Repository
Open Flags - Flags for
Repository::open_ext - Signature
- A Signature is used to indicate authorship of various actions throughout the library.
- Time
- Time in a signature
- Tree
- A structure to represent a git tree
Enums
- Branch
Type - An enumeration for the possible types of branches
- Direction
- An enumeration of the possible directions for a remote.
- Error
Class - An enumeration of possible categories of things that can have errors when working with a git repository.
- Error
Code - An enumeration of possible errors that can happen when working with a git repository.
- File
Mode - Valid modes for index and tree entries.
- Object
Type - An enumeration all possible kinds objects may have.
Traits
- Error
Ext - An extension trait for
git2::Errorto more conveniently handle errors with the codegit2::ErrorCode::NotFound.