Modules
Structs
- Payload
Upsert - A change (update or insertion) to particular
keywithin aPayloadin a document.
Enums
- Edit
Visibility EditVisibilityallows the visibility of aRawDocto be edited using thevisibilityfunction.
Functions
- delegates
- Change the delegates of the document and perform some verification based on the new set of delegates.
- payload
- Change (update or insert) a key in a
Payloadof the document, using the providedupdates. - privacy_
allow_ list - Change the
allowset of a document if the visibility is set toVisibility::Private. - verify
- Verify the document.
- visibility
- Change the visibility of the
RawDoc, using the providedEditVisibility.