Commands sent to the node via the control socket, and auxiliary types, as well as their results (responses on the socket).
Structs
- Connect
Options - Options passed to the “connect” node command.
- Success
- A success response.
Enums
- Command
- Command name.
- Command
Result - Result of a command, on the node control socket.
Constants
- DEFAULT_
TIMEOUT - Default timeout when waiting for the node to respond with data.