Module config

Modules

seeds
Configured public seeds.

Structs

Config
Service configuration.
ConnectAddress
Full address used to connect to a remote node.
ConnectionLimits
Connection limits.
FetchPackSizeLimit
Limiter for byte streams.
Limits
Configuration parameters defining attributes of minima and maxima.
RateLimit
Rate limts for a single connection.
RateLimits
Rate limits for inbound and outbound connections.

Enums

AddressConfig
Proxy configuration.
DefaultSeedingPolicy
Default seeding policy. Applies when no repository policies for the given repo are found.
Network
Peer-to-peer network.
PeerConfig
Peer configuration.
Relay
Relay configuration.

Constants

DEFAULT_WORKERS
Default number of workers to spawn.

Type Aliases

ProtocolVersion
Peer-to-peer protocol version.