This module contains definitions for use with the sqlite crate.
Enums
- Journal
Mode - Value for a
journal_modepragma statement. For a description of all variants please refer to https://sqlite.org/pragma.html#pragma_journal_mode. Note that when SQLite documentation talks about “the application”, the application linked against this crate, e.g. Radicle Node, Radicle CLI, and others, is meant. - Synchronous
- Value for a
synchronouspragma statement. For a description of all variants please refer to https://sqlite.org/pragma.html#pragma_synchronous.