Structs
- Address
- Peer public protocol address.
- Did
- Filter
- Inventory filter used for subscriptions and inventory comparison.
- Local
Duration - Time duration as measured locally.
- Local
Time - Local time.
- Public
Key - The public/verification key.
- Refs
- The published state of a local repository.
- RepoId
- A repository identifier.
- Signature
- Cryptographic signature.
- Timestamp
- Milliseconds since epoch.
Enums
- Disconnect
Reason - Disconnect reason.
- Event
- A service event.
- Message
- Message payload. These are the messages peers send to each other.
- Network
- Peer-to-peer network.
Traits
- Write
Storage - Allows access to individual storage repositories.
Type Aliases
- NodeId
- Public identifier of a node device in the network.