pub struct Profile {
pub home: Home,
pub storage: Storage,
pub keystore: Keystore,
pub public_key: PublicKey,
pub config: Config,
}Fields
home: Homestorage: Storagekeystore: Keystorepublic_key: PublicKeyconfig: ConfigImplementations
Sourceimpl Profile
impl Profile
pub fn init( home: Home, alias: Alias, passphrase: Option<Zeroizing<String>>, seed: Seed, ) -> Result<Profile, Error>
pub fn load() -> Result<Profile, Error>
pub fn id(&self) -> &PublicKey
pub fn info(&self) -> UserInfo
pub fn hints(&self) -> bool
pub fn did(&self) -> Did
pub fn signer(&self) -> Result<BoxedDevice, SignerError>
Sourcepub fn policies(&self) -> Result<Config<Read>, Error>
pub fn policies(&self) -> Result<Config<Read>, Error>
Return a read-only handle to the policies of the node.
Sourcepub fn add_inventory(&self, rid: RepoId, node: &mut Node) -> Result<bool, Error>
pub fn add_inventory(&self, rid: RepoId, node: &mut Node) -> Result<bool, Error>
Add the repo to our inventory. If the node is offline, adds it directly to the database.
Sourcepub fn seed(
&self,
rid: RepoId,
scope: Scope,
node: &mut Node,
) -> Result<bool, Error>
pub fn seed( &self, rid: RepoId, scope: Scope, node: &mut Node, ) -> Result<bool, Error>
Seed a repository by first trying to seed through the node, and if the node isn’t running, by updating the policy database directly. If the repo is available locally, we also add it to our inventory.
Sourcepub fn unseed(&self, rid: RepoId, node: &mut Node) -> Result<bool, Error>
pub fn unseed(&self, rid: RepoId, node: &mut Node) -> Result<bool, Error>
Unseed a repository by first trying to unseed through the node, and if the node isn’t running, by updating the policy database directly.
Sourcepub fn database_mut(&self) -> Result<Database, Error>
pub fn database_mut(&self) -> Result<Database, Error>
Return a handle to the database of the node, with SQLite configuration
from Self::config applied.
Methods from Deref<Target = Home>
pub fn path(&self) -> &Path
Sourcepub fn storage(&self) -> PathBuf
pub fn storage(&self) -> PathBuf
The /storage directory under Home::path.
Sourcepub fn config(&self) -> PathBuf
pub fn config(&self) -> PathBuf
The config.json file path under Home::path.
Sourcepub fn keys(&self) -> PathBuf
pub fn keys(&self) -> PathBuf
The /keys directory under Home::path.
Sourcepub fn node(&self) -> PathBuf
pub fn node(&self) -> PathBuf
The /node directory under Home::path.
Sourcepub fn cobs(&self) -> PathBuf
pub fn cobs(&self) -> PathBuf
The /cobs directory under Home::path.
pub fn socket(&self) -> PathBuf
Sourcepub fn notifications_mut(&self) -> Result<Store<Write>, Error>
pub fn notifications_mut(&self) -> Result<Store<Write>, Error>
Return a read-write handle to the notifications database.
Sourcepub fn policies_mut(&self) -> Result<Store<Write>, Error>
pub fn policies_mut(&self) -> Result<Store<Write>, Error>
Return a read-write handle to the policies store of the node.
Sourcepub fn database(&self, config: Config) -> Result<Database, Error>
pub fn database(&self, config: Config) -> Result<Database, Error>
Return a handle to a read-only database of the node.
Sourcepub fn database_mut(&self, config: Config) -> Result<Database, Error>
pub fn database_mut(&self, config: Config) -> Result<Database, Error>
Return a handle to the database of the node.
Sourcepub fn addresses(&self, config: Config) -> Result<impl Store, Error>
pub fn addresses(&self, config: Config) -> Result<impl Store, Error>
Returns the address store.
Sourcepub fn routing_mut(&self, config: Config) -> Result<impl Store, Error>
pub fn routing_mut(&self, config: Config) -> Result<impl Store, Error>
Returns the routing store, mutably.
Sourcepub fn issues<'a, R>(
&self,
repository: &'a R,
) -> Result<Cache<Issues<'a, R>, Store<Read>>, Error>
pub fn issues<'a, R>( &self, repository: &'a R, ) -> Result<Cache<Issues<'a, R>, Store<Read>>, Error>
Return a read-only handle for the issues cache.
Sourcepub fn issues_mut<'a, R>(
&self,
repository: &'a R,
) -> Result<Cache<Issues<'a, R>, Store<Write>>, Error>
pub fn issues_mut<'a, R>( &self, repository: &'a R, ) -> Result<Cache<Issues<'a, R>, Store<Write>>, Error>
Return a read-write handle for the issues cache.