Modules
Structs
- Ref
- A parsed Git reference.
- Repository
- Git implementation of
WriteRepositoryusing thegit2crate. - Storage
- Temp
Repository - A
Repositorythat is created for temporary operations, such as cloning. - Validations
- A set of
Validationerrors that a caller must use.
Enums
- Error
- Storage error.
- Repository
Error - Repository error.
- Validation
- Validation errors that can occur when verifying the layout of the
storage. These errors include checking the validity of the
rad/sigrefscontents and the identity of the repository.