Generic COB storage.
Modules
- access
- Stores carry
Accessto indicate allowed access modes. In particular whether writes to the store are allowed. - encoding
Structs
- Scope
- The
Scopeof aStorekeeps track of what collaborative object is being accessed. - Store
- Storage for collaborative objects of a specific type
Tin a single repository. - Transaction
- Allows operations to be batched atomically.
Enums
- Error
- Store error.
Traits
- Cob
- A collaborative object. Can be materialized from an operation history.
- CobAction
- CobWith
Type - Implementations are statically associated with a particular type name of a collaborative object.
Functions
- ops
- Get an object’s operations without decoding them.