Skip to main contentModule refs
Source - canonical
- draft
- Draft references.
- sigrefs
- staging
- Staging/temporary references.
- Refs
- The published state of a local repository.
- RefsAt
- The content-addressable information required to load a remote’s
rad/sigrefs. - SignedRefs
- Verified
SignedRefs that keeps track of their content address
Oid.
- Error
- FeatureLevel
- The Signed References feature has evolved over time.
This enum captures the corresponding “feature level”.
- Special
- The set of special references used in the Heartwood protocol.
- REFS_BLOB_PATH
- File in which the signed references are stored, in the
refs/rad/sigrefs branch. - SIGNATURE_BLOB_PATH
- File in which the signature over the references is stored in the
refs/rad/sigrefs branch.
- IDENTITY_BRANCH
- Where the repo’s identity document is stored.
- IDENTITY_ROOT
- Where the repo’s identity root document is stored.
- SIGREFS_BRANCH
- Where the project’s signed references are stored.
- SIGREFS_PARENT
- A reference to the parent commit.
- branch_of
- Create the
Namespaced branch under the remote namespace, i.e. - cob
- The collaborative object reference, identified by
typename and object_id, under the given remote. - cobs
- All collaborative objects, identified by
typename and object_id, for all remotes. - id
- Get the branch where the project’s identity document is stored.
- id_root
- Get the root of the branch where the project’s identity document is stored.
- sigrefs
- Get the branch where the
remote’s signed references are
stored.