Modules
- git
- Signed References are encoded in the Git commit graph. This module provides traits for interacting with a Git repository to read and write data for Signed References.
- read
- write
Structs
- Signed
Refs Reader - A
SignedRefsReaderreads and verifies a commit chain for arad/sigrefsentry. - Verified
Commit - A
rad/sigrefsthat has passed the following verification checks: