pub trait Reader {
// Required method
fn find_reference(
&self,
reference: &Namespaced<'_>,
) -> Result<Option<Oid>, FindReference>;
}Expand description
Git reference reader, generally a Git repository, or its corresponding Reference Database (Ref DB).
Required Methods
Sourcefn find_reference(
&self,
reference: &Namespaced<'_>,
) -> Result<Option<Oid>, FindReference>
fn find_reference( &self, reference: &Namespaced<'_>, ) -> Result<Option<Oid>, FindReference>
Find the head Oid of the sigrefs reference for the given namespace.
Returns None if the reference does not yet exist.
Errors
error::FindReference: failed to write the Git reference.