pub struct Committer {
pub author: Author,
}Expand description
Convenience type that corresponds to an Author.
Most users will want to instantiate this via Committer::from_env_or_now,
which automatically constructs a stable Author for tests as well.
Otherwise, an Author can be provided via Committer::new.
Fields
Implementations
Sourceimpl Committer
impl Committer
Sourcepub fn from_env_or_now(public_key: &PublicKey) -> Committer
pub fn from_env_or_now(public_key: &PublicKey) -> Committer
Construct a Committer using the timestamp found at
GIT_COMMITTER_DATE,
If GIT_COMMITTER_DATE is unset, it uses the current system
time.
The given PublicKey is always used for the email.
In test code, [Committer::stable] is returned.
pub fn into_inner(self) -> Author