Module wire
Source - StreamId
- Identifies a (multiplexed) stream.
- Wire
- Wire protocol implementation for a set of peers.
- AddressType
- Address type.
- Control
- Control message used internally between workers, users, and the service.
- Error
- MessageType
- Message type.
- Decode
- Things that can be decoded from binary.
- Encode
- Things that can be encoded as binary.
- deserialize
- Decode an object from a vector.
- serialize
- Encode an object into a byte vector.
- Size
- The default type we use to represent sizes on the wire.
- WireReader
- Peer session type (read-only).
- WireSession
- Peer session type.
- WireWriter
- Peer session type (write-only).